summaryrefslogtreecommitdiffstats
path: root/usr.bin/systat/systat.h
diff options
context:
space:
mode:
authorwollman <wollman@FreeBSD.org>1997-09-24 02:43:45 +0000
committerwollman <wollman@FreeBSD.org>1997-09-24 02:43:45 +0000
commit57eb2ca27ae0db0529c08d313a97117ed75cd0f8 (patch)
treed9d0748fd095f3ebbc0424d1780b409d6895560c /usr.bin/systat/systat.h
parentace16f9a4bb54d69518d6aaddf9ba9d6fe278e7c (diff)
downloadFreeBSD-src-57eb2ca27ae0db0529c08d313a97117ed75cd0f8.zip
FreeBSD-src-57eb2ca27ae0db0529c08d313a97117ed75cd0f8.tar.gz
Add a mode to display ICMP statistics.
Inspired by: IRIX netstat -C
Diffstat (limited to 'usr.bin/systat/systat.h')
-rw-r--r--usr.bin/systat/systat.h18
1 files changed, 10 insertions, 8 deletions
diff --git a/usr.bin/systat/systat.h b/usr.bin/systat/systat.h
index 72f65ff..72f0f28 100644
--- a/usr.bin/systat/systat.h
+++ b/usr.bin/systat/systat.h
@@ -30,20 +30,22 @@
* OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGE.
*
- * @(#)systat.h 8.1 (Berkeley) 6/6/93
+ * From: @(#)systat.h 8.1 (Berkeley) 6/6/93
+ * $Id$
*/
#include <curses.h>
struct cmdtab {
char *c_name; /* command name */
- void (*c_refresh)(); /* display refresh */
- void (*c_fetch)(); /* sets up data structures */
- void (*c_label)(); /* label display */
- int (*c_init)(); /* initialize namelist, etc. */
- WINDOW *(*c_open)(); /* open display */
- void (*c_close)(); /* close display */
- int (*c_cmd)(); /* display command interpreter */
+ void (*c_refresh)(void); /* display refresh */
+ void (*c_fetch)(void); /* sets up data structures */
+ void (*c_label)(void); /* label display */
+ int (*c_init)(void); /* initialize namelist, etc. */
+ WINDOW *(*c_open)(void); /* open display */
+ void (*c_close)(WINDOW *); /* close display */
+ int (*c_cmd)(char *, char *); /* display command interpreter */
+ void (*c_reset)(void); /* reset ``mode since'' display */
char c_flags; /* see below */
};
OpenPOWER on IntegriCloud